﻿using System;
using System.Text;
using System.Text.RegularExpressions;
using System.Web;
using System.Security.Cryptography;

namespace EasyCompany.Common
{
    public class Input
    {
        #region 检测是否整数型数据
        /// <summary>
        /// 检测是否整数型数据
        /// </summary>
        /// <param name="Num">待检查数据</param>
        /// <returns></returns>
        public static bool IsInteger(string input)
        {
            if (input == null)
            {
                return false;
            }
            else
            {
                return IsInteger(input, true);
            }
        }

        public static string CutStr(string str, int len)
        {
            if (str == null || str.Length == 0 || len <= 0) { return string.Empty; }
            int l = str.Length;
            #region 计算长度
            int clen = 0;
            while (clen < len && clen < l)
            {
                //每遇到一个中文，则将目标长度减一。          
                if ((int)str[clen] > 128) { len--; }
                clen++;
            }
            #endregion
            if (clen < l)
            {
                return str.Substring(0, clen) + "...";
            }
            else
            {
                return str;
            }
        }
        #endregion

        #region  是否全是正整数
        /// <summary>
        /// 是否全是正整数
        /// </summary>
        /// <param name="Input"></param>
        /// <returns></returns>
        public static bool IsInteger(string Input, bool Plus)
        {
            if (Input == null)
            {
                return false;
            }
            else
            {
                string pattern = "^-?[0-9]+$";
                if (Plus)
                    pattern = "^[0-9]+$";
                if (Regex.Match(Input, pattern, RegexOptions.Compiled).Success)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }
        #endregion

        #region  判断输入是否为日期类型
        /// <summary>
        /// 判断输入是否为日期类型
        /// </summary>
        /// <param name="s">待检查数据</param>
        /// <returns></returns>
        public static bool IsDate(string s)
        {
            try
            {
                DateTime d = DateTime.Parse(s);
                return true;
            }
            catch
            {
                return false;
            }
        }
        #endregion

        #region  过滤字符串中的html代码
        /// <summary>
        /// 过滤字符串中的html代码
        /// </summary>
        /// <param name="Str"></param>
        /// <returns>返回过滤之后的字符串</returns>
        public static string LostHTML(string Str)
        {
            string Re_Str = "";
            if (Str != null)
            {
                if (Str != string.Empty)
                {
                    string Pattern = "<\\/*[^<>]*>";
                    Re_Str = Regex.Replace(Str, Pattern, "");
                }
            }
            return (Re_Str.Replace("\\r\\n", "")).Replace("\\r", "");
        }

        public static string LostPage(string Str)
        {
            string Re_Str = "";
            if (Str != null)
            {
                if (Str != string.Empty)
                {
                    string Pattern = "\\[YX:PAGE\\/*[^<>]*\\$\\]";
                    Re_Str = Regex.Replace(Str, Pattern, "");
                }
            }
            return Re_Str;
        }

        public static string LostVoteStr(string Str)
        {
            string Re_Str = "";
            if (Str != null)
            {
                if (Str != string.Empty)
                {
                    string Pattern = "\\[YX:unLoop\\/*[^<>]*\\[\\/YX:unLoop\\]";
                    Re_Str = Regex.Replace(Str, Pattern, "");
                }
            }
            return Re_Str;
        }

        #endregion

        #region  根据新闻标题的属性设置返回设置后的标题
        /// <summary>
        /// 根据新闻标题的属性设置返回设置后的标题
        /// </summary>
        /// <param name="Title">标题</param>
        /// <param name="TitleColor">标题颜色</param>
        /// <param name="IsB">是否粗体</param>
        /// <param name="IsI">是否斜体</param>
        /// <param name="TitleNum">返回标题字数</param>
        /// <returns>返回设置后的标题</returns>
        public static string GetColorTitleSubStr(string Title, string TitleColor, int IsB, int IsI, int TitleNum)
        {
            string Return_title = "";
            string FormatTitle = LostHTML(Title);
            if (FormatTitle != null && FormatTitle != string.Empty)
            {
                if (TitleNum != 0)
                    FormatTitle = CutStr(FormatTitle, TitleNum);
                if (IsB == 1)
                {
                    FormatTitle = "<b>" + FormatTitle + "</b>";
                }
                if (IsI == 1)
                {
                    FormatTitle = "<i>" + FormatTitle + "</i>";
                }
                if (TitleColor != null && TitleColor != string.Empty)
                {
                    FormatTitle = "<font style=\"color:" + TitleColor + ";\">" + FormatTitle + "</font>";
                }
                Return_title = FormatTitle;
            }
            return Return_title;
        }
        #endregion

        #region  截取字符串函数
        /// <summary>
        /// 截取字符串函数
        /// </summary>
        /// <param name="Str">所要截取的字符串</param>
        /// <param name="Num">截取字符串的长度</param>
        /// <returns></returns>
        public static string GetSubString(string Str, int Num)
        {
            if (Str == null || Str == "")
                return "";
            string outstr = "";
            int n = 0;
            foreach (char ch in Str)
            {
                n += System.Text.Encoding.Default.GetByteCount(ch.ToString());
                if (n > Num)
                    break;
                else
                    outstr += ch;
            }
            return outstr;
        }
        #endregion

        #region 截取字符串函数
        /// <summary>
        /// 截取字符串函数
        /// </summary>
        /// <param name="Str">所要截取的字符串</param>
        /// <param name="Num">截取字符串的长度</param>
        /// <param name="Num">截取字符串后省略部分的字符串</param>
        /// <returns></returns>
        public static string GetSubString(string Str, int Num, string LastStr)
        {
            return (Str.Length > Num) ? Str.Substring(0, Num) + LastStr : Str;
        }
        #endregion

        #region 验证字符串是否是图片路径
        /// <summary>
        /// 验证字符串是否是图片路径
        /// </summary>
        /// <param name="Input">待检测的字符串</param>
        /// <returns>返回true 或 false</returns>
        public static bool IsImgString(string Input)
        {
            return IsImgString(Input, "/{@dirfile}/");
        }

        public static bool IsImgString(string Input, string checkStr)
        {
            bool re_Val = false;
            if (Input != string.Empty)
            {
                string s_input = Input.ToLower();
                if (s_input.IndexOf(checkStr.ToLower()) != -1 && s_input.IndexOf(".") != -1)
                {
                    string Ex_Name = s_input.Substring(s_input.LastIndexOf(".") + 1).ToString().ToLower();
                    if (Ex_Name == "jpg" || Ex_Name == "gif" || Ex_Name == "bmp" || Ex_Name == "png")
                    {
                        re_Val = true;
                    }
                }
            }
            return re_Val;
        }
        #endregion

        #region 将字符转化为HTML编码

        /// <summary>
        ///  将字符转化为HTML编码
        /// </summary>
        /// <param name="str">待处理的字符串</param>
        /// <returns></returns>
        public static string HtmlEncode(string Input)
        {
            return HttpContext.Current.Server.HtmlEncode(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="Input"></param>
        /// <returns></returns>
        public static string HtmlDecode(string Input)
        {
            return HttpContext.Current.Server.HtmlDecode(Input);
        }
        #endregion

        #region  URL地址
        /// <summary>
        /// URL地址编码
        /// </summary>
        /// <param name="Input"></param>
        /// <returns></returns>
        public static string URLEncode(string Input)
        {
            return HttpContext.Current.Server.UrlEncode(Input);
        }

        /// <summary>
        /// URL地址解码
        /// </summary>
        /// <param name="Input"></param>
        /// <returns></returns>
        public static string URLDecode(string Input)
        {
            return HttpContext.Current.Server.UrlDecode(Input);
        }

        #endregion

        #region 过滤字符(防SQL注入)
        /// <summary>
        /// 过滤字符(防SQL注入)
        /// </summary>
        /// <param name="Input"></param>
        /// <returns></returns>
        public static string Filter(string sInput)
        {
            if (sInput == null || sInput == "")
                return sInput;
            string sInput1 = sInput.ToLower();
            string output = sInput;
            string pattern = @"*|and|exec|insert|select|delete|update|count|master|truncate|declare|char(|mid(|chr(|'";
            if (Regex.Match(sInput1, Regex.Escape(pattern), RegexOptions.Compiled | RegexOptions.IgnoreCase).Success)
            {
                throw new Exception("字符串中含有非法字符!");
            }
            else
            {
                output = output.Replace("'", "''");
            }
            return output;
        }
        #endregion

        #region 过滤特殊字符/前台会员
        /// <summary>
        /// 过滤特殊字符/前台会员
        /// </summary>
        /// <param name="Input"></param>
        /// <returns></returns>
        public static string Htmls(string Input)
        {
            if (Input != string.Empty && Input != null)
            {
                string ihtml = Input.ToLower();
                ihtml = ihtml.Replace("<script", "&lt;script");
                ihtml = ihtml.Replace("script>", "script&gt;");
                ihtml = ihtml.Replace("<%", "&lt;%");
                ihtml = ihtml.Replace("%>", "%&gt;");
                ihtml = ihtml.Replace("<$", "&lt;$");
                ihtml = ihtml.Replace("$>", "$&gt;");
                return ihtml;
            }
            else
            {
                return string.Empty;
            }
        }
        #endregion

        #region 字符串字符处理
        /// <summary>
        /// 字符串字符处理
        /// </summary>
        /// <param name="chr">等待处理的字符串</param>
        /// <returns>处理后的字符串</returns>
        /// //把HTML代码转换成TXT格式
        public static String ToTxt(String Input)
        {
            StringBuilder sb = new StringBuilder(Input);
            sb.Replace("&nbsp;", " ");
            sb.Replace("<br>", "\r\n");
            sb.Replace("<br>", "\n");
            sb.Replace("<br />", "\n");
            sb.Replace("<br />", "\r\n");
            sb.Replace("&lt;", "<");
            sb.Replace("&gt;", ">");
            sb.Replace("&amp;", "&");
            return sb.ToString();
        }

        #endregion

        #region 字符串字符处理
        /// <summary>
        /// 字符串字符处理
        /// </summary>
        /// <param name="chr">等待处理的字符串</param>
        /// <returns>处理后的字符串</returns>
        /// //把HTML代码转换成TXT格式
        public static String ToshowTxt(String Input)
        {
            StringBuilder sb = new StringBuilder(Input);
            sb.Replace("&lt;", "<");
            sb.Replace("&gt;", ">");
            sb.Replace("&amp;", "&");
            return sb.ToString();
        }
        #endregion

        #region 把字符转化为文本格式
        /// <summary>
        /// 把字符转化为文本格式
        /// </summary>
        /// <param name="Input"></param>
        /// <returns></returns>
        public static string ForTXT(string Input)
        {
            StringBuilder sb = new StringBuilder(Input);
            sb.Replace("<font", " ");
            sb.Replace("<span", " ");
            sb.Replace("<style", " ");
            sb.Replace("<div", " ");
            sb.Replace("<p", "");
            sb.Replace("</p>", "");
            sb.Replace("<label", " ");
            sb.Replace("&nbsp;", " ");
            sb.Replace("<br>", "");
            sb.Replace("<br />", "");
            sb.Replace("<br />", "");
            sb.Replace("&lt;", "");
            sb.Replace("&gt;", "");
            sb.Replace("&amp;", "");
            sb.Replace("<", "");
            sb.Replace(">", "");
            return sb.ToString();
        }

        #endregion

        #region 字符串字符处理
        /// <summary>
        /// 字符串字符处理
        /// </summary>
        /// <param name="chr">等待处理的字符串</param>
        /// <returns>处理后的字符串</returns>
        /// //把TXT代码转换成HTML格式

        public static String ToHtml(string Input)
        {
            StringBuilder sb = new StringBuilder(Input);
            sb.Replace("&", "&amp;");
            sb.Replace("<", "&lt;");
            sb.Replace(">", "&gt;");
            sb.Replace("\r\n", "<br />");
            sb.Replace("\n", "<br />");
            sb.Replace("\t", " ");
            //sb.Replace(" ", "&nbsp;");
            return sb.ToString();
        }
        #endregion

        #region 加密字符串处理
        /// <summary>
        /// MD5加密字符串处理
        /// </summary>
        /// <param name="Half">加密是16位还是32位；如果为true为16位</param>
        /// <param name="Input">待加密码字符串</param>
        /// <returns></returns>
        public static string MD5(string Input, bool Half)
        {
            string output = System.Web.Security.FormsAuthentication.HashPasswordForStoringInConfigFile(Input, "MD5").ToLower();
            if (Half)//16位MD5加密（取32位加密的9~25字符）
                output = output.Substring(8, 16);
            return output;
        }

        public static string MD5(string Input)
        {
            return MD5(Input, true);
        }
        #endregion

        #region 字符串加密  进行位移操作
        /// <summary>
        /// 字符串加密  进行位移操作
        /// </summary>
        /// <param name="str">待加密数据</param>
        /// <returns>加密后的数据</returns>
        public static string EncryptString(string Input)
        {
            string _temp = "";
            int _inttemp;
            char[] _chartemp = Input.ToCharArray();
            for (int i = 0; i < _chartemp.Length; i++)
            {
                _inttemp = _chartemp[i] + 1;
                _chartemp[i] = (char)_inttemp;
                _temp += _chartemp[i];
            }
            return _temp;
        }
        #endregion

        #region 字符串解密
        /// <summary>
        /// 字符串解密
        /// </summary>
        /// <param name="str">待解密数据</param>
        /// <returns>解密成功后的数据</returns>
        public static string NcyString(string Input)
        {
            string _temp = "";
            int _inttemp;
            char[] _chartemp = Input.ToCharArray();
            for (int i = 0; i < _chartemp.Length; i++)
            {
                _inttemp = _chartemp[i] - 1;
                _chartemp[i] = (char)_inttemp;
                _temp += _chartemp[i];
            }
            return _temp;
        }

        #endregion

        #region 检测含中文字符串实际长度
        /// <summary>
        /// 检测含中文字符串实际长度
        /// </summary>
        /// <param name="str">待检测的字符串</param>
        /// <returns>返回正整数</returns>
        public static int NumChar(string Input)
        {
            ASCIIEncoding n = new ASCIIEncoding();
            byte[] b = n.GetBytes(Input);
            int l = 0;
            for (int i = 0; i <= b.Length - 1; i++)
            {
                if (b[i] == 63)//判断是否为汉字或全脚符号
                {
                    l++;
                }
                l++;
            }
            return l;
        }

        #endregion

        #region 检测是否合法日期
        /// <summary>
        /// 检测是否合法日期
        /// </summary>
        /// <param name="str">待检测的字符串</param>
        /// <returns></returns>
        public static bool ChkDate(string Input)
        {
            try
            {
                DateTime t1 = DateTime.Parse(Input);
                return true;
            }
            catch
            {
                return false;
            }
        }
        #endregion

        #region 转换日期时间函数
        /// <summary>
        /// 转换日期时间函数
        /// </summary>
        /// <returns></returns>        
        public static string ReDateTime(string str)
        {
           // return System.DateTime.Now.ToString("yyyyMMdd");
            return Convert.ToDateTime(str).ToString("yyyyMMdd");
        }
        #endregion

        #region 去除字符串最后一个','号
        /// <summary>
        /// 去除字符串最后一个','号
        /// </summary>
        /// <param name="chr">:要做处理的字符串</param>
        /// <returns>返回已处理的字符串</returns>
        /// /// CreateTime:2007-03-26 Code By DengXi
        public static string CutComma(string Input)
        {
            return CutComma(Input, ",");
        }

        public static string CutComma(string Input, string indexStr)
        {
            if (Input.IndexOf(indexStr) >= 0)
                return Input.Remove(Input.LastIndexOf(indexStr));
            else
                return Input;
        }

        #endregion

        #region 去掉首尾P
        /// <summary>
        /// 去掉首尾P
        /// </summary>
        /// <param name="Input"></param>
        /// <returns></returns>
        public static string RemovePor(string Input)
        {
            if (Input != string.Empty && Input != null)
            {
                string TMPStr = Input;
                if (Input.ToLower().Substring(0, 3) == "<p>")
                {
                    TMPStr = TMPStr.Substring(3);
                }
                if (TMPStr.Substring(TMPStr.Length - 4) == "</p>")
                {
                    TMPStr = TMPStr.Remove(TMPStr.ToLower().LastIndexOf("</p>"));
                }
                return TMPStr;
            }
            else
            {
                return string.Empty;
            }
        }
        #endregion

        #region 判断参数是否合法
        /// <summary>
        /// 判断参数是否合法
        /// </summary>
        /// <param name="ID">要判断的参数</param>
        /// <returns>返回已处理的字符串</returns>

        public static string checkID(string ID)
        {
            if (ID == null && ID == string.Empty)
                throw new Exception("参数传递错误!<li>参数不能为空</li>");
            return ID;
        }

        #endregion

        #region 去除编号字符串中的'-1'
        /// <summary>
        /// 去除编号字符串中的'-1'
        /// </summary>
        /// <param name="id"></param>
        /// <returns>如果为空则返回'IsNull'</returns>

        public static string Losestr(string id)
        {
            if (id == null || id == "" || id == string.Empty)
                return "IsNull";

            id = id.Replace("'-1',", "");

            if (id == null || id == "" || id == string.Empty)
                return "IsNull";
            else
                return id;
        }
        #endregion

        #region 去掉在线编辑器里面的关键字
        /// <summary>
        /// 去掉在线编辑器里面的关键字
        /// </summary>
        /// <param name="html"></param>
        /// <returns></returns>
        public static string FilterHTML(string html)
        {
            if (html == null)
                return "";
            System.Text.RegularExpressions.Regex regex1 = new System.Text.RegularExpressions.Regex(@"<script[\s\S]+</script *>", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
            System.Text.RegularExpressions.Regex regex2 = new System.Text.RegularExpressions.Regex(@" href *= *[\s\S]*script *:", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
            System.Text.RegularExpressions.Regex regex3 = new System.Text.RegularExpressions.Regex(@" on[\s\S]*=", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
            System.Text.RegularExpressions.Regex regex4 = new System.Text.RegularExpressions.Regex(@"<iframe[\s\S]+</iframe *>", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
            System.Text.RegularExpressions.Regex regex5 = new System.Text.RegularExpressions.Regex(@"<frameset[\s\S]+</frameset *>", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
            System.Text.RegularExpressions.Regex regex6 = new System.Text.RegularExpressions.Regex(@"\<img[^\>]+\>", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
            System.Text.RegularExpressions.Regex regex7 = new System.Text.RegularExpressions.Regex(@"</p>", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
            System.Text.RegularExpressions.Regex regex8 = new System.Text.RegularExpressions.Regex(@"<p>", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
            System.Text.RegularExpressions.Regex regex9 = new System.Text.RegularExpressions.Regex(@"<[^>]*>", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
            html = regex1.Replace(html, ""); //过滤<script></script>标记
            html = regex2.Replace(html, ""); //过滤href=javascript: (<A>) 属性
            html = regex3.Replace(html, " _disibledevent="); //过滤其它控件的on...事件
            html = regex4.Replace(html, ""); //过滤iframe
            html = regex5.Replace(html, ""); //过滤frameset
            html = regex6.Replace(html, ""); //过滤frameset
            html = regex7.Replace(html, ""); //过滤frameset
            html = regex8.Replace(html, ""); //过滤frameset
            html = regex9.Replace(html, "");
            html = html.Replace(" ", "");
            html = html.Replace("</strong>", "");
            html = html.Replace("<strong>", "");
            return html;
        }
        #endregion

        #region 过滤特殊字符
        /// <summary>
        /// 过滤特殊字符
        /// </summary>
        /// <param name="inputStr">字符串</param>
        /// <returns>string</returns>
        public static string cutBadStr(string inputStr)
        {
            if (!string.IsNullOrEmpty(inputStr))
            {
                //inputStr = inputStr.ToLower().Replace(",", "");
                inputStr = inputStr.ToLower().Replace("<", "&lt;");
                inputStr = inputStr.ToLower().Replace(">", "&gt;");
                inputStr = inputStr.ToLower().Replace("%", "");
                //inputStr = inputStr.ToLower().Replace(":", "");
                inputStr = inputStr.ToLower().Replace("#", "");
                inputStr = inputStr.ToLower().Replace("&", "");
                inputStr = inputStr.ToLower().Replace("$", "");
                inputStr = inputStr.ToLower().Replace("^", "");
                inputStr = inputStr.ToLower().Replace("*", "");
                inputStr = inputStr.ToLower().Replace("`", "");
                inputStr = inputStr.ToLower().Replace(" ", "");
                inputStr = inputStr.ToLower().Replace("~", "");
                inputStr = inputStr.ToLower().Replace("or", "");
                inputStr = inputStr.ToLower().Replace("and", "");
            }
            return inputStr;
        }
        #endregion

        #region 返回地址信息
        /// <summary>
        /// 返回地址信息
        /// </summary>
        /// <param name="videourl"></param>
        /// <returns></returns>
        public static string GetVideoInfo(string videourl, int width, int heigth)
        {
            if (string.IsNullOrEmpty(videourl)) return "视频地址不能为空";
            if (!videourl.StartsWith("http://") && !videourl.StartsWith("/")) return "视频地址不正确";
            int pos1 = videourl.LastIndexOf('.');
            if (pos1 < 1) return "视频格式错误";
            string fileExName = videourl.Substring(pos1);
            string content = "";
            switch (fileExName.ToLower())
            {
                case ".jpg":
                case ".gif":
                case ".bmp":
                case ".ico":
                case ".png":
                case ".jpeg":
                case ".tif":
                case ".rar":
                case ".doc":
                case ".zip":
                case ".txt":
                    return "格式错误";
                case ".swf":
                    content = "<object classid=\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\" codebase=\"http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,19,0\">\n";
                    content += "<param name=\"movie\" value=\"" + videourl + "\" />\n";
                    content += "<param name=\"quality\" value=\"high\" />\n";
                    content += "<embed src=\"" + videourl + "\" quality=\"high\" pluginspage=\"http://www.macromedia.com/go/getflashplayer\" type=\"application/x-shockwave-flash\"></embed>\n";
                    content += "</object>\n";
                    break;
                case ".flv":
                    content = "<embed src=\"/FlvPlayer.swf?id=" + videourl + "\" width=\"" + width + "\" height=\"" + heigth + "\" type=\"application/x-shockwave-flash\" wmode=\"transparent\" quality=\"high\" autostart=\"true\"></embed>\n";
                    break;
                default:
                    content = "<object id=\"player\" name=\"player\" classid=\"clsid:CFCDAA03-8BE4-11cf-B84B-0020AFBBCCFA\" width=\"" + width + "\" height=\"" + heigth + "\">\n";
                    content += "<param name=_ExtentX value=18415>\n";
                    content += "<param name=_ExtentY value=9102>\n";
                    content += "<param name=AUTOSTART value=-1>\n";
                    content += "<param name=SHUFFLE value=0>\n";
                    content += "<param name=PREFETCH value=0>\n";
                    content += "<param name=NOLABELS value=-1>\n";
                    content += "<param name=SRC value=\"" + videourl + "\">\n";
                    content += "<param name=CONTROLS value=Imagewindow>\n";
                    content += "<param name=CONSOLE value=clip1>\n";
                    content += "<param name=LOOP value=0>\n";
                    content += "<param name=NUMLOOP value=0>\n";
                    content += "<param name=CENTER value=0>\n";
                    content += "<param name=MAINTAINASPECT value=0>\n";
                    content += "<param name=BACKGROUNDCOLOR value=#000000>\n";
                    content += "</object><br>\n";
                    content += "<object ID=RP2 CLASSID=clsid:CFCDAA03-8BE4-11cf-B84B-0020AFBBCCFA WIDTH=" + width + " HEIGHT=50>\n";
                    content += "<param name=_ExtentX value=18415>\n";
                    content += "<param name=_ExtentY value=1005>\n";
                    content += "<param name=AUTOSTART value=-1>\n";
                    content += "<param name=SHUFFLE value=0>\n";
                    content += "<param name=PREFETCH value=0>\n";
                    content += "<param name=NOLABELS value=-1>\n";
                    content += "<param name=SRC value=\"" + videourl + "\">\n";
                    content += "<PARAM NAME=CONTROLS VALUE=ControlPanel,StatusBar>\n";
                    content += "<param name=CONSOLE value=clip1>\n";
                    content += "<param name=LOOP value=0>\n";
                    content += "<param name=NUMLOOP value=0>\n";
                    content += "<param name=CENTER value=0>\n";
                    content += "<param name=MAINTAINASPECT value=0>\n";
                    content += "<param name=BACKGROUNDCOLOR value=#000000>\n";
                    content += "</object>\n";
                    break;
            }
            return content;
        }
        #endregion


        public static string GetEnumName(string typeid)
        {
            string _output = string.Empty;
            switch (typeid)
            {
                case "1":
                    _output = "文本框";
                    break;
                case "2":
                    _output = "文本区域";
                    break;
                case "3":
                    _output = "单选框";
                    break;
                case "4":
                    _output = "复选框";
                    break;
                case "5":
                    _output = "下拉框";
                    break;
                case "6":
                    _output = "密码框";
                    break;
                case "7":
                    _output = "Email地址";
                    break;
            }
            return _output;
        }

        /// <summary>
        /// 返回表单内容
        /// </summary>
        /// <param name="inputid"></param>
        /// <param name="f_state"></param>
        /// <param name="f_option"></param>
        /// <param name="f_width"></param>
        /// <returns></returns>
        public static string htmlinput(int inputid, int f_state, string f_option, int f_width)
        {
            string tempstr = string.Empty;
            string[] t_option = null;
            switch (f_state)
            {
                case 1:
                    tempstr = "<input type=text name='form" + inputid + "' size=" + f_width + " maxlength=" + f_width + ">";
                    break;
                case 2:
                    tempstr = "<TEXTAREA NAME='form" + inputid + "' ROWS='5' style='width:95%;'></TEXTAREA>";
                    break;
                case 3:
                    t_option = f_option.Split('|');
                    for (int ii = 1; ii <= t_option.Length; ii++)
                    {
                        tempstr += "<input type='radio' name='form" + inputid + "' value='" + t_option[ii - 1] + "'> " + t_option[ii - 1];
                        if (ii % 4 == 0) tempstr += "<BR>";
                    }
                    break;
                case 4:
                    t_option = f_option.Split('|');
                    for (int ii = 1; ii <= t_option.Length; ii++)
                    {
                        tempstr += "<input type='checkbox' name='form" + inputid + "' value='" + t_option[ii - 1] + "'> " + t_option[ii - 1];
                        if (ii % 4 == 0) tempstr += "<BR>";
                    }
                    break;
                case 5:
                    t_option = f_option.Split('|');
                    tempstr = "<select name='form" + inputid + "' size='1'>";
                    for (int ii = 1; ii <= t_option.Length; ii++)
                    {
                        tempstr += "<option value=" + t_option[ii - 1] + ">" + t_option[ii - 1] + "</option>";
                    }
                    tempstr += "</select>";
                    break;
                case 6:
                    tempstr = "<input type=password name='form" + inputid + "' size=" + f_width + " maxlength=" + f_width + ">";
                    break;
                case 7:
                    tempstr = "<input type=text name='form" + inputid + "' size=" + f_width + " maxlength=" + f_width + ">";
                    break;
            }
            return tempstr;
        }
    }
}
